"""
Type constants for uploader configurations.

This module defines constants for different uploader types supported
by the data exchange agent.
"""

UPLOADER_TYPES = {"snowflake-stage", "s3", "bucket", "blob"}
